#
# spec file for package maven-jar-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "bootstrap"
%bcond_without bootstrap
%else
%bcond_with bootstrap
%endif
%global base_name maven-jar-plugin
Version:        3.3.0
Release:        3.1
Summary:        Maven JAR Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugins/maven-jar-plugin/
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugins/%{base_name}/%{version}/%{base_name}-%{version}-source-release.zip
Source1:        %{base_name}-build.xml
Patch0:         %{base_name}-bootstrap-resources.patch
Patch1:         01-allow-replacing-artifacts.patch
Patch2:         reproducible-from-environment.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildRequires:  maven-archiver >= 3.5.0
BuildRequires:  maven-file-management
BuildRequires:  maven-lib
BuildRequires:  maven-plugin-annotations
BuildRequires:  plexus-archiver >= 4.2.0
BuildRequires:  plexus-utils >= 3.3.0
BuildRequires:  unzip
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildArch:      noarch
%if %{with bootstrap}
Name:           %{base_name}-bootstrap
BuildRequires:  ant
%else
Name:           %{base_name}
BuildRequires:  xmvn
BuildRequires:  mvn(org.apache.maven.plugins:maven-compiler-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-jar-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-javadoc-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-resources-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-surefire-plugin)
Obsoletes:      %{base_name}-bootstrap
#!BuildRequires: maven-compiler-plugin-bootstrap
#!BuildRequires: maven-jar-plugin-bootstrap
#!BuildRequires: maven-javadoc-plugin-bootstrap
#!BuildRequires: maven-plugin-plugin-bootstrap
#!BuildRequires: maven-resources-plugin-bootstrap
#!BuildRequires: maven-surefire-plugin-bootstrap
%endif

%description
Builds a Java Archive (JAR) file from the compiled
project classes and resources.

%if %{without bootstrap}
%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.
%endif

%prep
%setup -q -n %{base_name}-%{version}
%if %{with bootstrap}
cp %{SOURCE1} build.xml
%patch -P 0 -p1
%endif
%patch -P 1 -p1
%patch -P 2 -p1

# Remove all dependencies with scope test, since a raw xmvn does not hide them
%pom_remove_dep -r :::test:

%build
# Test class MockArtifact doesn't override method getMetadata
%if %{with bootstrap}
mkdir -p lib
build-jar-repository -s lib \
    maven-file-management/file-management \
    maven-archiver/maven-archiver \
    maven/maven-artifact \
    maven/maven-core \
    maven/maven-plugin-api \
    maven-plugin-tools/maven-plugin-annotations \
    plexus/archiver \
    plexus/utils
%{ant} -Dtest.skip=true jar
%else
xmvn --batch-mode --offline \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dmaven.test.skip=true -DmavenVersion=3.1.1 \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    package org.apache.maven.plugins:maven-javadoc-plugin:aggregate
%endif

%{mvn_artifact} pom.xml target/%{base_name}-%{version}.jar

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%dir %{_javadir}/%{name}
%license LICENSE
%doc NOTICE

%if %{without bootstrap}
%files javadoc -f .mfiles-javadoc
%license LICENSE
%doc NOTICE
%endif

%changelog
* Mon Sep 23 2024 Fridrich Strba <fstrba@suse.com>
- Use SOURCE_DATE_EPOCH for reproducible builds
- Added patch:
  * reproducible-from-environment.patch
    + SOURCE_DATE_EPOCH environmental variable triggers reproducible
    use of the maven-jar-plugin if it is not requested already
    using the project.build.outputTimestamp option.
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Sep 20 2023 Fridrich Strba <fstrba@suse.com>
- Update to upstream version 3.3.0
  * Bug
    + MJAR-275: outputTimestamp not applied to module-info; breaks
    reproducible builds
  * Task
    + MJAR-278: Update plugin (requires Maven 3.2.5+)
    + MJAR-280: Java 8 as minimum
  * Dependency upgrade
    + MJAR-283: Upgrade Plexus Utils to 3.3.1
    + MJAR-284: Remove override for Plexus Archiver to fix order of
    META-INF/ and META-INF/MANIFEST.MF entries
    + MJAR-288: Upgrade Parent to 36
    + MJAR-290: Update Plexus Utils to 3.4.2
    + MJAR-291: Upgrade Parent to 37
- Modified patches:
  * 01-allow-replacing-artifacts.patch
    + rediff to changed context
  * maven-jar-plugin-bootstrap-resources.patch
    + regenerate in cycle
* Fri Jun 24 2022 Fridrich Strba <fstrba@suse.com>
- Remove all dependencies with scope test, since a raw xmvn does
  not hide them from maven.
* Tue Mar 29 2022 Fridrich Strba <fstrba@suse.com>
- Update to upstream version 3.2.2
  * Bugs:
    + MJAR-276 - Don't log a warning when jar will be empty and
    creation is forced
    + MJAR-281 - Wrong order of META-INF/ and
    META-INF/MANIFEST.MF entries
  * Improvement:
    + MJAR-270 - make build Reproducible
  * Dependency upgrades:
    + MJAR-282 - Upgrade Maven Archiver to 3.5.2
    + MJAR-283 - Upgrade Plexus Utils to 3.3.1
    + MJAR-284 - Remove override for Plexus Archiver to fix order
    of META-INF/ and META-INF/MANIFEST.MF entries
- Modified patch:
  * 01-allow-replacing-artifacts.patch
    + rediff to different line endings
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Mon Nov 25 2019 Fridrich Strba <fstrba@suse.com>
- Update to version 3.2.0
  * Bugs:
    + MJAR-259 – Archiving to jar is very slow
    + MJAR-241 – Jar package does not have a size in ZipEntry
  * Improvements:
    + MJAR-260 – Upgrade to Archiver 3.3.0 and add ITs
    + MJAR-238 – Allow setting of module main class
  * New Feature:
    + MJAR-263 – Reproducible Builds: make entries in output jar
    files reproducible (order + timestamp)
  * Task:
    + MJAR-251 – Add documentation information for GitHub
  * Dependency upgrades:
    + MJAR-261 – Upgrade plexus-archiver 3.7.0
    + MJAR-256 – Upgrade JUnit to 4.12
    + MJAR-255 – Upgrade maven-plugins parent to version 32
    + MJAR-252 – Upgrade plexus-archiver to 3.6.0
- Modified patch:
  * maven-jar-plugin-bootstrap-resources.patch
    + regenerate from non-bootstrap build
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Tue Oct  8 2019 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * 01-allow-replacing-artifacts.patch
    + Warn but do not fail with misconfigured plugin
* Mon Apr  1 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-jar-plugin 3.1.0 as a multibuild
  package in order to be able to bootstrap a repository
- Generate and customize maven build.xml file for the bootstrap
  variant
- Added patch:
  * maven-jar-plugin-bootstrap-resources.patch
    + For the bootstrap variant, add the pre-generated resources
    in order to be able to build even without
    maven-plugin-plugin
